#[non_exhaustive]pub enum ContextAttachmentError {
DuplicateAttachment,
RoleOccupied(ContextAttachmentRole),
MissingPlatform,
ContextDropping,
}Expand description
Failure to register an attachment with a Context.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DuplicateAttachment
An attachment with the same marker type is already active.
RoleOccupied(ContextAttachmentRole)
The exclusive platform or renderer role is already occupied.
MissingPlatform
A renderer cannot attach until a platform runtime is registered.
ContextDropping
Context teardown has already started.