#[non_exhaustive]pub enum ContextBindingError {
Dropping,
NativeDestroyed,
}Expand description
Failure to enter a Context through a persistent binding capability.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Dropping
Context teardown has started, so ordinary safe access is no longer permitted.
NativeDestroyed
The originating native Context no longer exists.