#[non_exhaustive]pub enum ContextPlatformWindowTeardownError {
ContextDropping,
Reentrant,
AttachmentPreflight(ContextAttachmentTeardownError),
AttachmentPostflight(ContextAttachmentTeardownError),
BeginPanicked,
EndPanicked,
}Expand description
Failure while entering or leaving an explicit platform-window teardown transaction.
Unlike ContextAttachmentTeardownError, this error is returned to the caller of
[crate::Context::destroy_platform_windows] before or after its native operation. It does not
use Context-drop’s fail-stop policy because the caller still owns a live Context.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ContextDropping
The Context is already being dropped.
Reentrant
A platform-window teardown transaction attempted to re-enter itself.
AttachmentPreflight(ContextAttachmentTeardownError)
The active platform attachment rejected the transaction before native teardown began.
AttachmentPostflight(ContextAttachmentTeardownError)
The active platform attachment failed after native teardown completed.
BeginPanicked
The active platform attachment panicked before native teardown began.
EndPanicked
The active platform attachment panicked after native teardown completed.