NumericFormatError

Enum NumericFormatError 

#[non_exhaustive]
pub enum NumericFormatError {
Show 14 variants FormatTooLong { byte_offset: usize, length: usize, maximum: usize, }, InteriorNul { byte_offset: usize, }, UnterminatedDirective { byte_offset: usize, }, MultipleConversions { byte_offset: usize, }, DynamicArgument { byte_offset: usize, }, PositionalArgument { byte_offset: usize, }, UnsupportedFlag { byte_offset: usize, flag: char, }, IncompatibleFlag { byte_offset: usize, flag: char, conversion: char, }, WidthTooLarge { byte_offset: usize, width: u32, maximum: u32, }, PrecisionTooLarge { byte_offset: usize, precision: u32, maximum: u32, }, UnsupportedLength { byte_offset: usize, }, UnsupportedConversion { byte_offset: usize, conversion: char, }, TypeMismatch { byte_offset: usize, }, DirectiveTooLong { byte_offset: usize, length: usize, },
}
Describes why a C-style numeric format was rejected.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


FormatTooLong

The complete UTF-8 format exceeds the bounded native parsing contract.

Fields

byte_offset: usize
length: usize
maximum: usize


InteriorNul

The string contains a NUL byte and cannot be passed as one C string.

Fields

byte_offset: usize


UnterminatedDirective

A % directive is incomplete.

Fields

byte_offset: usize


MultipleConversions

More than one directive would consume a value argument.

Fields

byte_offset: usize


DynamicArgument

* requests another variadic width or precision argument.

Fields

byte_offset: usize


PositionalArgument

A positional argument such as %1$d was requested.

Fields

byte_offset: usize


UnsupportedFlag

The directive uses a non-portable or unsupported flag.

Fields

byte_offset: usize
flag: char


IncompatibleFlag

The flag is defined for printf but not for this numeric conversion.

Fields

byte_offset: usize
flag: char
conversion: char


WidthTooLarge

The requested field width exceeds the bounded native parsing contract.

Fields

byte_offset: usize
width: u32
maximum: u32


PrecisionTooLarge

The requested precision exceeds the bounded native parsing contract.

Fields

byte_offset: usize
precision: u32
maximum: u32


UnsupportedLength

The directive uses a length modifier that does not match the C carrier type.

Fields

byte_offset: usize


UnsupportedConversion

The directive is not a supported numeric conversion.

Fields

byte_offset: usize
conversion: char


TypeMismatch

The conversion is numeric but does not match the signedness or category of T.

Fields

byte_offset: usize


DirectiveTooLong

Dear ImGui copies directives into a fixed 32-byte stack buffer.

Fields

byte_offset: usize
length: usize

Implementations

Source

impl NumericFormatError

pub fn byte_offset(&self) -> usize

Returns the byte offset where validation failed.