OldColumnOffsetRef

Enum OldColumnOffsetRef 

pub enum OldColumnOffsetRef {
    Current,
    Column(OldColumnIndex),
    Trailing,
}
Legacy column offset-line selector.

Offset APIs operate on column boundary lines. Concrete column indices select the start line for that column, while OldColumnOffsetRef::Trailing selects the right-most line after the final column.

Variants



Current

Use the current legacy column boundary.



Column(OldColumnIndex)

Use the start boundary for a concrete legacy column.



Trailing

Use the right-most boundary after the final legacy column.

Implementations

Source

impl OldColumnOffsetRef

pub const CURRENT: Self = Self::Current

Current legacy column boundary.

pub const TRAILING: Self = Self::Trailing

Right-most boundary after the final legacy column.

pub const fn column(index: OldColumnIndex) -> Self

Select the start boundary for a concrete legacy column.