ScopedActivationError

Enum ScopedActivationError 

#[non_exhaustive]
pub enum ScopedActivationError<E> { Scope(ContextScopeError), Closure(E), }
Failure while temporarily activating a borrowed SuspendedContext.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Scope(ContextScopeError)

The temporary Context scope could not be entered or completed.



Closure(E)

The caller’s closure returned an error.

Implementations

Source

impl<E> ScopedActivationError<E>

pub fn map_closure<F>(self, f: impl FnOnce(E) -> F) -> ScopedActivationError<F>

Maps only the caller-provided closure error.

pub fn scope_error(&self) -> Option<ContextScopeError>

Returns the Context-scope failure, if the caller’s closure did not return an error.

pub fn activation_reason(&self) -> Option<ContextActivationReason>

Returns the activation rejection reason, if the closure was not entered.

pub fn closure_error(&self) -> Option<&E>

Returns the caller-provided closure error, if one was returned.

pub fn into_closure_error(self) -> Result<E, ContextScopeError>

Extracts the caller-provided closure error or returns the Context-scope failure.