StyleVarVec2

Enum StyleVarVec2 

#[non_exhaustive]
pub enum StyleVarVec2 { WindowPadding, WindowMinSize, WindowTitleAlign, FramePadding, ItemSpacing, ItemInnerSpacing, CellPadding, TableAngledHeadersTextAlign, ButtonTextAlign, SelectableTextAlign, SeparatorTextAlign, SeparatorTextPadding, }
A two-component style variable whose X or Y component can be overridden.

Use this with Ui::push_style_var_x or Ui::push_style_var_y. Scalar style variables are intentionally not representable by this type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WindowPadding

Padding within a window.



WindowMinSize

Minimum window size.



WindowTitleAlign

Alignment for title bar text.



FramePadding

Padding within a framed rectangle.



ItemSpacing

Horizontal and vertical spacing between widgets or lines.



ItemInnerSpacing

Spacing between elements of a composed widget.



CellPadding

Padding within a table cell.



TableAngledHeadersTextAlign

Alignment of angled table headers within the cell.



ButtonTextAlign

Alignment of button text when the button is larger than its text.



SelectableTextAlign

Alignment of selectable text when the selectable is larger than its text.



SeparatorTextAlign

Alignment of text within a separator.



SeparatorTextPadding

Padding around text in a separator.