pub enum TableSizingPolicy {
FixedFit,
FixedSame,
StretchProp,
StretchSame,
}Expand description
Single-choice table sizing policy.
Variants
FixedFit
Columns default to fixed/auto widths matching contents width.
FixedSame
Fixed/auto widths matching the maximum contents width of all columns.
StretchProp
Stretch columns with weights proportional to contents widths.
StretchSame
Stretch columns with equal weights unless overridden per column.