WindowLabel

Enum WindowLabel 

#[non_exhaustive]
pub enum WindowLabel<'a> { Plain(Cow<'a, str>), Keyed { key: &'a WindowKey, title: Cow<'a, str>, }, }
Window label accepted by Ui::window.

Plain strings retain Dear ImGui’s native ##/### behavior. Labels created by WindowKey::label always append the validated stable identity after the displayed title.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Plain(Cow<'a, str>)



Keyed

Fields

key: &'a WindowKey
title: Cow<'a, str>

Implementations

Source

impl WindowLabel<'_>

pub fn title(&self) -> &str

Return the displayed title supplied to Dear ImGui.

pub fn key(&self) -> Option<&WindowKey>

Return the stable key, when this label is keyed.