pub struct InputTextMultilineFlags(/* private fields */);Expand description
Independent flags accepted by InputTextMultiline() widgets.
Implementations
Sourceimpl InputTextMultilineFlags
impl InputTextMultilineFlags
Sourcepub const CHARS_DECIMAL: Self
pub const CHARS_DECIMAL: Self
Allow 0123456789.+-*/
Sourcepub const CHARS_HEXADECIMAL: Self
pub const CHARS_HEXADECIMAL: Self
Allow 0123456789ABCDEFabcdef
Sourcepub const CHARS_SCIENTIFIC: Self
pub const CHARS_SCIENTIFIC: Self
Allow 0123456789.+-*/eE (Scientific notation input)
Sourcepub const CHARS_UPPERCASE: Self
pub const CHARS_UPPERCASE: Self
Turn a..z into A..Z
Sourcepub const CHARS_NO_BLANK: Self
pub const CHARS_NO_BLANK: Self
Filter out spaces, tabs
Sourcepub const ALLOW_TAB_INPUT: Self
pub const ALLOW_TAB_INPUT: Self
Pressing TAB input a ‘\t’ character into the text field.
Sourcepub const ENTER_RETURNS_TRUE: Self
pub const ENTER_RETURNS_TRUE: Self
Return true when Enter is pressed.
Sourcepub const ESCAPE_CLEARS_ALL: Self
pub const ESCAPE_CLEARS_ALL: Self
Escape key clears content if not empty, and deactivates otherwise.
Sourcepub const CTRL_ENTER_FOR_NEW_LINE: Self
pub const CTRL_ENTER_FOR_NEW_LINE: Self
In multi-line mode, unfocus with Enter, add new line with Ctrl+Enter.
Sourcepub const ALWAYS_OVERWRITE: Self
pub const ALWAYS_OVERWRITE: Self
Overwrite mode.
Sourcepub const AUTO_SELECT_ALL: Self
pub const AUTO_SELECT_ALL: Self
Select entire text when first taking mouse focus.
Sourcepub const NO_HORIZONTAL_SCROLL: Self
pub const NO_HORIZONTAL_SCROLL: Self
Disable following the cursor horizontally.
Sourcepub const NO_UNDO_REDO: Self
pub const NO_UNDO_REDO: Self
Disable undo/redo.
Sourcepub const CALLBACK_ALWAYS: Self
pub const CALLBACK_ALWAYS: Self
Callback on each iteration.
Sourcepub const CALLBACK_CHAR_FILTER: Self
pub const CALLBACK_CHAR_FILTER: Self
Callback on character inputs to replace or discard them.
Sourcepub const CALLBACK_EDIT: Self
pub const CALLBACK_EDIT: Self
Callback on any edit.
Sourceimpl InputTextMultilineFlags
impl InputTextMultilineFlags
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl InputTextMultilineFlags
impl InputTextMultilineFlags
Sourcepub const fn iter(&self) -> Iter<InputTextMultilineFlags>
pub const fn iter(&self) -> Iter<InputTextMultilineFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<InputTextMultilineFlags>
pub const fn iter_names(&self) -> IterNames<InputTextMultilineFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.