ColorButtonFlags

Struct ColorButtonFlags 

pub struct ColorButtonFlags(/* private fields */);
Independently composable flags accepted by ColorButton().

Implementations

Source

impl ColorButtonFlags

pub const NONE: Self

No flags.

pub const NO_ALPHA: Self

Ignore Alpha component. For ColorButton() this does the same as Self::ALPHA_OPAQUE.

pub const NO_TOOLTIP: Self

Disable tooltip when hovering the preview.

pub const NO_DRAG_DROP: Self

Disable drag and drop source.

pub const NO_BORDER: Self

Disable border (which is enforced by default).

pub const ALPHA_OPAQUE: Self

Disable alpha in the preview.

pub const ALPHA_NO_BG: Self

Disable the checkerboard background behind transparent colors.

pub const ALPHA_PREVIEW: Self

Compatibility alias for Self::ALPHA_NO_BG.

pub const ALPHA_PREVIEW_HALF: Self

Display half opaque / half checkerboard, instead of opaque.

Source

impl ColorButtonFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl ColorButtonFlags

pub const fn iter(&self) -> Iter<ColorButtonFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ColorButtonFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.