pub struct ColorEditFlags(/* private fields */);Expand description
Flags for color edit widgets
Implementations
Sourceimpl ColorEditFlags
impl ColorEditFlags
Sourcepub const NO_ALPHA: Self
pub const NO_ALPHA: Self
ColorEdit, ColorPicker, ColorButton: ignore Alpha component (will only read 3 components from the input pointer).
Sourcepub const NO_OPTIONS: Self
pub const NO_OPTIONS: Self
ColorEdit: disable toggling options menu when right-clicking on inputs/small preview.
Sourcepub const NO_SMALL_PREVIEW: Self
pub const NO_SMALL_PREVIEW: Self
ColorEdit, ColorPicker: disable color square preview next to the inputs. (e.g. to show only the inputs)
Sourcepub const NO_INPUTS: Self
pub const NO_INPUTS: Self
ColorEdit, ColorPicker: disable inputs sliders/text widgets (e.g. to show only the small preview color square).
Sourcepub const NO_TOOLTIP: Self
pub const NO_TOOLTIP: Self
ColorEdit, ColorPicker, ColorButton: disable tooltip when hovering the preview.
Sourcepub const NO_LABEL: Self
pub const NO_LABEL: Self
ColorEdit, ColorPicker: disable display of inline text label (the label is still forwarded to the tooltip and picker).
Sourcepub const NO_SIDE_PREVIEW: Self
pub const NO_SIDE_PREVIEW: Self
ColorPicker: disable bigger color preview on right side of the picker, use small color square preview instead.
Sourcepub const NO_DRAG_DROP: Self
pub const NO_DRAG_DROP: Self
ColorEdit: disable drag and drop target. ColorButton: disable drag and drop source.
Sourcepub const NO_COLOR_MARKERS: Self
pub const NO_COLOR_MARKERS: Self
ColorEdit: disable rendering R/G/B/A color markers.
Sourcepub const ALPHA_OPAQUE: Self
pub const ALPHA_OPAQUE: Self
ColorEdit, ColorPicker, ColorButton: disable alpha in the preview.
Sourcepub const ALPHA_NO_BG: Self
pub const ALPHA_NO_BG: Self
ColorEdit, ColorPicker, ColorButton: disable the checkerboard background behind transparent colors.
Sourcepub const ALPHA_PREVIEW: Self = Self::ALPHA_NO_BG
pub const ALPHA_PREVIEW: Self = Self::ALPHA_NO_BG
Compatibility alias for Self::ALPHA_NO_BG.
Sourcepub const ALPHA_PREVIEW_HALF: Self
pub const ALPHA_PREVIEW_HALF: Self
ColorEdit, ColorPicker, ColorButton: display half opaque / half checkerboard, instead of opaque.