pub struct DragDropSourceFlags(/* private fields */);Expand description
Flags for drag and drop sources.
Implementations
Sourceimpl DragDropSourceFlags
impl DragDropSourceFlags
Sourcepub const NO_PREVIEW_TOOLTIP: Self
pub const NO_PREVIEW_TOOLTIP: Self
Disable preview tooltip during drag
Sourcepub const NO_DISABLE_HOVER: Self
pub const NO_DISABLE_HOVER: Self
Don’t disable hover during drag
Sourcepub const NO_HOLD_TO_OPEN_OTHERS: Self
pub const NO_HOLD_TO_OPEN_OTHERS: Self
Don’t open tree nodes/headers when hovering during drag
Sourcepub const ALLOW_NULL_ID: Self
pub const ALLOW_NULL_ID: Self
Allow items without unique ID to be drag sources
Sourcepub const PAYLOAD_AUTO_EXPIRE: Self
pub const PAYLOAD_AUTO_EXPIRE: Self
Automatically expire payload if source stops being submitted
Sourcepub const PAYLOAD_NO_CROSS_CONTEXT: Self
pub const PAYLOAD_NO_CROSS_CONTEXT: Self
Hint that the payload may not be copied outside the current Dear ImGui context
Sourcepub const PAYLOAD_NO_CROSS_PROCESS: Self
pub const PAYLOAD_NO_CROSS_PROCESS: Self
Hint that the payload may not be copied outside the current process
Sourceimpl DragDropSourceFlags
impl DragDropSourceFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DragDropSourceFlags
impl DragDropSourceFlags
Sourcepub const fn iter(&self) -> Iter<DragDropSourceFlags>
pub const fn iter(&self) -> Iter<DragDropSourceFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DragDropSourceFlags>
pub const fn iter_names(&self) -> IterNames<DragDropSourceFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.