pub struct DragFlags(/* private fields */);Expand description
Flags for drag widgets.
Dear ImGui shares the underlying ImGuiSliderFlags enum between drag
and slider widgets, but WRAP_AROUND is supported by DragXXX only.
Implementations
Sourceimpl DragFlags
impl DragFlags
Sourcepub const WRAP_AROUND: Self
pub const WRAP_AROUND: Self
Wrap the value around when exceeding the current range.
Sourcepub const CLAMP_ON_INPUT: Self
pub const CLAMP_ON_INPUT: Self
Clamp on input when editing via CTRL+Click or direct text input.
Sourcepub const CLAMP_ZERO_RANGE: Self
pub const CLAMP_ZERO_RANGE: Self
Clamp zero-range drags to avoid a zero-sized range.
Sourcepub const NO_SPEED_TWEAKS: Self
pub const NO_SPEED_TWEAKS: Self
Disable small “smart” speed tweaks for very small/large ranges.
Sourcepub const ALWAYS_CLAMP: Self
pub const ALWAYS_CLAMP: Self
Clamp value to min/max bounds when input manually with CTRL+Click.
Sourcepub const LOGARITHMIC: Self
pub const LOGARITHMIC: Self
Make the widget logarithmic.
Sourcepub const NO_ROUND_TO_FORMAT: Self
pub const NO_ROUND_TO_FORMAT: Self
Disable rounding underlying value to match the display format.
Sourcepub const COLOR_MARKERS: Self
pub const COLOR_MARKERS: Self
Draw R/G/B/A color markers on each component.
Dear ImGui only defines four default component colors.
Sourceimpl DragFlags
impl DragFlags
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DragFlags
impl DragFlags
Sourcepub const fn iter(&self) -> Iter<DragFlags>
pub const fn iter(&self) -> Iter<DragFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DragFlags>
pub const fn iter_names(&self) -> IterNames<DragFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.