DrawListTextureToken

Struct DrawListTextureToken 

pub struct DrawListTextureToken<'draw_list, 'tex> { /* private fields */ }
Tracks a texture pushed to a draw-list texture stack.

The texture is popped when the token is dropped or when Self::pop is called explicitly.

Implementations

Source

impl<'draw_list, 'tex> DrawListTextureToken<'draw_list, 'tex>

pub fn pop(self)

Pop the texture immediately instead of waiting for drop.

pub fn end(self)

Pop the texture immediately instead of waiting for drop.