pub struct MultiSelectFlags(/* private fields */);Expand description
Independent flags controlling multi-selection behavior.
The click-selection policy, box-select mode, and scope are represented by
MultiSelectClickPolicy, MultiSelectBoxSelect, and MultiSelectScopeKind.
Implementations
Sourceimpl MultiSelectFlags
impl MultiSelectFlags
Sourcepub const SINGLE_SELECT: Self
pub const SINGLE_SELECT: Self
Single-selection scope. Ctrl/Shift range selection is disabled.
Sourcepub const NO_SELECT_ALL: Self
pub const NO_SELECT_ALL: Self
Disable Ctrl+A “select all” shortcut.
Sourcepub const NO_RANGE_SELECT: Self
pub const NO_RANGE_SELECT: Self
Disable range selection (Shift+click / Shift+arrow).
Sourcepub const NO_AUTO_SELECT: Self
pub const NO_AUTO_SELECT: Self
Disable automatic selection of newly focused items.
Sourcepub const NO_AUTO_CLEAR: Self
pub const NO_AUTO_CLEAR: Self
Disable automatic clearing of selection when focus moves within the scope.
Sourcepub const NO_AUTO_CLEAR_ON_RESELECT: Self
pub const NO_AUTO_CLEAR_ON_RESELECT: Self
Disable automatic clearing when reselecting the same range.
Sourcepub const BOX_SELECT_NO_SCROLL: Self
pub const BOX_SELECT_NO_SCROLL: Self
Disable drag-scrolling when box-selecting near edges of the scope.
Sourcepub const CLEAR_ON_ESCAPE: Self
pub const CLEAR_ON_ESCAPE: Self
Clear selection when pressing Escape while the scope is focused.
Sourcepub const CLEAR_ON_CLICK_VOID: Self
pub const CLEAR_ON_CLICK_VOID: Self
Clear selection when clicking on empty space (void) inside the scope.
Sourcepub const NO_SELECT_ON_RIGHT_CLICK: Self
pub const NO_SELECT_ON_RIGHT_CLICK: Self
Disable default right-click behavior that selects item before opening a context menu.
Sourceimpl MultiSelectFlags
impl MultiSelectFlags
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MultiSelectFlags
impl MultiSelectFlags
Sourcepub const fn iter(&self) -> Iter<MultiSelectFlags>
pub const fn iter(&self) -> Iter<MultiSelectFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MultiSelectFlags>
pub const fn iter_names(&self) -> IterNames<MultiSelectFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.