OwnedStateStorage

Struct OwnedStateStorage 

pub struct OwnedStateStorage { /* private fields */ }
Owns an ImGuiStorage and clears it on drop.

This is useful when you want to keep widget state outside of the current window storage (e.g. sharing state across windows or providing custom storage for a widget subtree via Ui::push_state_storage).

Implementations

Source

impl OwnedStateStorage

pub fn new() -> Self

pub fn as_mut(&mut self) -> &mut ImGuiStorage

pub fn as_ref(&self) -> &ImGuiStorage

pub fn as_raw_mut(&mut self) -> *mut ImGuiStorage

pub fn as_raw(&self) -> *const ImGuiStorage