TableColumnStateFlags

Struct TableColumnStateFlags 

pub struct TableColumnStateFlags(/* private fields */);
Flags returned by TableGetColumnFlags().

Implementations

Source

impl TableColumnStateFlags

pub const NONE: Self

No flags

pub const DISABLED: Self

Overriding/master disable flag: hide column and omit it from the context menu.

pub const DEFAULT_HIDE: Self

Default to a hidden/disabled column.

pub const DEFAULT_SORT: Self

Default to a sorting column.

pub const WIDTH_FIXED: Self

Overriding width becomes fixed width

pub const WIDTH_STRETCH: Self

Overriding width becomes weight

pub const NO_RESIZE: Self

Disable manual resizing

pub const NO_REORDER: Self

Disable manual reordering this column

pub const NO_HIDE: Self

Disable ability to hide/disable this column

pub const NO_CLIP: Self

Disable clipping for this column

pub const NO_SORT: Self

Disable ability to sort on this field

pub const NO_SORT_ASCENDING: Self

Disable ability to sort in the ascending direction

pub const NO_SORT_DESCENDING: Self

Disable ability to sort in the descending direction

pub const NO_HEADER_LABEL: Self

TableHeadersRow() will not submit label for this column

pub const NO_HEADER_WIDTH: Self

Disable header text width contribution to automatic column width

pub const PREFER_SORT_ASCENDING: Self

Make the initial sort direction Ascending when first sorting on this column

pub const PREFER_SORT_DESCENDING: Self

Make the initial sort direction Descending when first sorting on this column

pub const INDENT_ENABLE: Self

Use current Indent value when entering cell

pub const INDENT_DISABLE: Self

Disable indenting for this column

pub const ANGLED_HEADER: Self

Display an angled header for this column (when angled headers feature is enabled)

pub const IS_ENABLED: Self

Status: is enabled == not hidden

pub const IS_VISIBLE: Self

Status: is visible == is enabled AND not clipped by scrolling

pub const IS_SORTED: Self

Status: is currently part of the sort specs

pub const IS_HOVERED: Self

Status: is hovered by mouse

Source

impl TableColumnStateFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> i32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: i32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: i32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: i32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl TableColumnStateFlags

pub const fn iter(&self) -> Iter<TableColumnStateFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<TableColumnStateFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.