pub struct VerticalStackLayoutToken<'a>(/* private fields */);Expand description
Tracks a stack-layout vertical group.
This wraps the repository-owned stack layout compatibility shim used by the upstream imgui-node-editor blueprints example. It is not part of the official Dear ImGui API.
Implementations
Sourceimpl<'a> VerticalStackLayoutToken<'a>
impl<'a> VerticalStackLayoutToken<'a>