pub struct WindowHoveredFlags(/* private fields */);Expand description
Flags accepted by Ui::is_window_hovered_with_flags().
Implementations
Sourceimpl WindowHoveredFlags
impl WindowHoveredFlags
Sourcepub const NONE: Self
pub const NONE: Self
Return true if directly over the item/window, not obstructed by another window, not obstructed by an active popup or modal blocking inputs under them.
Sourcepub const CHILD_WINDOWS: Self
pub const CHILD_WINDOWS: Self
IsWindowHovered() only: Return true if any children of the window is hovered
Sourcepub const ROOT_WINDOW: Self
pub const ROOT_WINDOW: Self
IsWindowHovered() only: Test from root window (top most parent of the current hierarchy)
Sourcepub const ANY_WINDOW: Self
pub const ANY_WINDOW: Self
IsWindowHovered() only: Return true if any window is hovered
Sourcepub const NO_POPUP_HIERARCHY: Self
pub const NO_POPUP_HIERARCHY: Self
IsWindowHovered() only: Do not consider popup hierarchy (do not treat popup emitter as parent of popup) (when used with _ChildWindows or _RootWindow)
Sourcepub const DOCK_HIERARCHY: Self
pub const DOCK_HIERARCHY: Self
IsWindowHovered() only: Consider docking hierarchy (treat dockspace host as parent of docked window) (when used with _ChildWindows or _RootWindow)
Sourcepub const ALLOW_WHEN_BLOCKED_BY_POPUP: Self
pub const ALLOW_WHEN_BLOCKED_BY_POPUP: Self
Return true even if a popup window is normally blocking access to this item/window
Sourcepub const ALLOW_WHEN_BLOCKED_BY_ACTIVE_ITEM: Self
pub const ALLOW_WHEN_BLOCKED_BY_ACTIVE_ITEM: Self
Return true even if an active item is blocking access to this item/window. Useful for Drag and Drop patterns.
Sourcepub const ROOT_AND_CHILD_WINDOWS: Self
pub const ROOT_AND_CHILD_WINDOWS: Self
IsWindowHovered() only: Shortcut for ROOT_WINDOW | CHILD_WINDOWS.
Sourcepub const FOR_TOOLTIP: Self
pub const FOR_TOOLTIP: Self
Shortcut for standard flags when using IsWindowHovered() + tooltip-style hover behavior.
Sourcepub const STATIONARY: Self
pub const STATIONARY: Self
Require mouse to be stationary for style.HoverStationaryDelay (~0.15 sec) at least one time.
Sourceimpl WindowHoveredFlags
impl WindowHoveredFlags
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WindowHoveredFlags
impl WindowHoveredFlags
Sourcepub const fn iter(&self) -> Iter<WindowHoveredFlags>
pub const fn iter(&self) -> Iter<WindowHoveredFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WindowHoveredFlags>
pub const fn iter_names(&self) -> IterNames<WindowHoveredFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.