ManagedTextureError

Enum ManagedTextureError 

#[non_exhaustive]
pub enum ManagedTextureError { ForeignContext { expected: ContextId, actual: ContextId, }, UnknownSlot(ManagedTextureId), StaleGeneration(ManagedTextureId), Retiring(ManagedTextureId), AlreadyRetiring(ManagedTextureId), AlreadyRemoved(ManagedTextureId), ForeignFontAtlas, DuplicateFeedback(ManagedTextureId), InvalidFeedbackStatus { id: ManagedTextureId, status: TextureStatus, }, }
Failure to access or retire a Context-owned managed texture.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ForeignContext

The handle belongs to another Context.

Fields

expected: ContextId

Context used for the attempted operation.

actual: ContextId

Context encoded in the handle.



UnknownSlot(ManagedTextureId)

The handle does not identify a slot allocated by this Context.



StaleGeneration(ManagedTextureId)

The slot has been reused for a newer texture generation.



Retiring(ManagedTextureId)

Removal has started and new drawing or mutation is no longer accepted.



AlreadyRetiring(ManagedTextureId)

Removal was already requested and is waiting for renderer retirement.



AlreadyRemoved(ManagedTextureId)

The texture was already fully removed.



ForeignFontAtlas

An atlas-backed texture was used with a Context that does not own that atlas.



DuplicateFeedback(ManagedTextureId)

One feedback batch addressed the same texture more than once.



InvalidFeedbackStatus

Renderer feedback may acknowledge only an uploaded or destroyed texture.

Fields

id: ManagedTextureId

Texture addressed by the feedback.

status: TextureStatus

Status rejected before native mutation.