TextureDataError

Enum TextureDataError 

#[non_exhaustive]
pub enum TextureDataError {
Show 14 variants InvalidDimensions { width: u32, height: u32, }, WidthOutOfRange(u32), HeightOutOfRange(u32), ByteSizeOutOfRange { width: u32, height: u32, bytes_per_pixel: usize, }, InvalidLayout { width: i32, height: i32, bytes_per_pixel: i32, }, ByteLengthMismatch { expected: usize, actual: usize, }, InvalidStatus(TextureStatus), MissingPixelStorage(TextureStatus), FullUpdateRectOutOfRange { width: u32, height: u32, }, InvalidRegionDimensions { width: u32, height: u32, }, UpdateRegionOutOfBounds { region: TextureRegion, width: u32, height: u32, }, UpdateRegionNotRepresentable(TextureRegion), RowPitchTooSmall { minimum: usize, actual: usize, }, PayloadSizeOutOfRange { row_pitch: usize, height: u32, },
}
Validation failure while creating or mutating CPU-side texture data.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidDimensions

Width or height was zero.

Fields

width: u32

Requested texture width.

height: u32

Requested texture height.



WidthOutOfRange(u32)

Width does not fit Dear ImGui’s signed native dimension field.



HeightOutOfRange(u32)

Height does not fit Dear ImGui’s signed native dimension field.



ByteSizeOutOfRange

The native allocation size overflowed or exceeded its signed size limit.

Fields

width: u32

Texture width.

height: u32

Texture height.

bytes_per_pixel: usize

Bytes per pixel.



InvalidLayout

Native metadata is not a valid texture layout.

Fields

width: i32

Native width.

height: i32

Native height.

bytes_per_pixel: i32

Native bytes per pixel.



ByteLengthMismatch

The supplied payload does not exactly match the requested byte contract.

Fields

expected: usize

Required payload length.

actual: usize

Supplied payload length.



InvalidStatus(TextureStatus)

Pixel mutation is unavailable in the WantDestroy or Destroyed lifecycle state.



MissingPixelStorage(TextureStatus)

A live texture does not have CPU-side pixel storage.



FullUpdateRectOutOfRange

The full texture cannot be represented by Dear ImGui’s 16-bit update rectangle.

Fields

width: u32

Texture width.

height: u32

Texture height.



InvalidRegionDimensions

A subresource region has a zero width or height.

Fields

width: u32

Requested region width.

height: u32

Requested region height.



UpdateRegionOutOfBounds

A subresource rectangle exceeds the texture bounds.

Fields

region: TextureRegion

Requested region.

width: u32

Texture width.

height: u32

Texture height.



UpdateRegionNotRepresentable(TextureRegion)

A live update region cannot be represented by Dear ImGui’s native update queue.



RowPitchTooSmall

The supplied row pitch cannot hold one tightly packed source row.

Fields

minimum: usize

Minimum tightly packed row size.

actual: usize

Supplied row pitch.



PayloadSizeOutOfRange

Computing the strided payload size overflowed.

Fields

row_pitch: usize

Supplied row pitch.

height: u32

Rectangle height.