pub type ButtonRepeatToken<'ui> = ItemFlagStackToken<'ui>;Expand description
Tracks a button repeat item flag pushed with Ui::push_button_repeat.
Aliased Type
pub struct ButtonRepeatToken<'ui> { /* private fields */ }pub type ButtonRepeatToken<'ui> = ItemFlagStackToken<'ui>;Tracks a button repeat item flag pushed with Ui::push_button_repeat.
pub struct ButtonRepeatToken<'ui> { /* private fields */ }