#[non_exhaustive]pub enum ScopedActivationError<E> {
Scope(ContextScopeError),
Closure(E),
}Expand description
Failure while temporarily activating a borrowed SuspendedContext.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Scope(ContextScopeError)
The temporary Context scope could not be entered or completed.
Closure(E)
The caller’s closure returned an error.
Implementations
Sourceimpl<E> ScopedActivationError<E>
impl<E> ScopedActivationError<E>
Sourcepub fn map_closure<F>(self, f: impl FnOnce(E) -> F) -> ScopedActivationError<F>
pub fn map_closure<F>(self, f: impl FnOnce(E) -> F) -> ScopedActivationError<F>
Maps only the caller-provided closure error.
Sourcepub fn scope_error(&self) -> Option<ContextScopeError>
pub fn scope_error(&self) -> Option<ContextScopeError>
Returns the Context-scope failure, if the caller’s closure did not return an error.
Sourcepub fn activation_reason(&self) -> Option<ContextActivationReason>
pub fn activation_reason(&self) -> Option<ContextActivationReason>
Returns the activation rejection reason, if the closure was not entered.
Sourcepub fn closure_error(&self) -> Option<&E>
pub fn closure_error(&self) -> Option<&E>
Returns the caller-provided closure error, if one was returned.
Sourcepub fn into_closure_error(self) -> Result<E, ContextScopeError>
pub fn into_closure_error(self) -> Result<E, ContextScopeError>
Extracts the caller-provided closure error or returns the Context-scope failure.