pub struct TableColumnSetup<Name> {
pub name: Name,
pub flags: TableColumnFlags,
pub width: Option<TableColumnWidth>,
pub indent: Option<TableColumnIndent>,
pub user_data: TableColumnUserData,
}Expand description
Table column setup information
Fields
name: Nameflags: TableColumnFlagswidth: Option<TableColumnWidth>indent: Option<TableColumnIndent>user_data: TableColumnUserDataImplementations
Sourceimpl<Name> TableColumnSetup<Name>
impl<Name> TableColumnSetup<Name>
Sourcepub fn flags(self, flags: TableColumnFlags) -> Self
pub fn flags(self, flags: TableColumnFlags) -> Self
Sets the column flags
Sourcepub fn fixed_width(self, width: f32) -> Self
pub fn fixed_width(self, width: f32) -> Self
Sets a fixed initial column width in pixels.
Sourcepub fn stretch_weight(self, weight: f32) -> Self
pub fn stretch_weight(self, weight: f32) -> Self
Sets an initial stretch weight for this column.
Sourcepub fn indent(self, indent: TableColumnIndent) -> Self
pub fn indent(self, indent: TableColumnIndent) -> Self
Sets this column’s indentation policy.
Sourcepub fn indent_enabled(self, enabled: bool) -> Self
pub fn indent_enabled(self, enabled: bool) -> Self
Enables or disables indentation for this column.
Sourcepub fn user_data(self, user_data: impl Into<TableColumnUserData>) -> Self
pub fn user_data(self, user_data: impl Into<TableColumnUserData>) -> Self
Sets the opaque user data associated with this column.
Dear ImGui returns the value unchanged in table sort specifications. The default is zero, which remains ordinary application data rather than an absence sentinel.
The old user_id API intentionally has no compatibility alias because widget IDs and
opaque column data have different semantics.
ⓘ
let _ = TableColumnSetup::new("column").user_id(1_u32);Trait Implementations
Sourceimpl<Name: Clone> Clone for TableColumnSetup<Name>
impl<Name: Clone> Clone for TableColumnSetup<Name>
Sourcefn clone(&self) -> TableColumnSetup<Name>
fn clone(&self) -> TableColumnSetup<Name>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<Name> Freeze for TableColumnSetup<Name>where
Name: Freeze,
impl<Name> RefUnwindSafe for TableColumnSetup<Name>where
Name: RefUnwindSafe,
impl<Name> Send for TableColumnSetup<Name>where
Name: Send,
impl<Name> Sync for TableColumnSetup<Name>where
Name: Sync,
impl<Name> Unpin for TableColumnSetup<Name>where
Name: Unpin,
impl<Name> UnsafeUnpin for TableColumnSetup<Name>where
Name: UnsafeUnpin,
impl<Name> UnwindSafe for TableColumnSetup<Name>where
Name: UnwindSafe,